# How to Change AI Backends and Large Language Models?

Enter ".model" in ToolMate AI prompt and follow the dialogs.

Alternately, press the `ENTER` key to enter a blank entry, to launch the ToolMate AI action menu.  Choose `change AI backends and models` and click `Ok`.

## Screenshots:

![select_model_1](https://github.com/eliranwong/toolmate/assets/25262722/179cd040-b7c4-4592-b2b4-f152a9ec1772)

![select_model_2](https://github.com/eliranwong/toolmate/assets/25262722/ff3f4b94-97e0-48f7-9e0d-49cf195321e8)

![select_model_3](https://github.com/eliranwong/toolmate/assets/25262722/ad79f5c1-5bd8-480c-9428-5d1e704ee153)

![select_model_4](https://github.com/eliranwong/toolmate/assets/25262722/0183c0ec-9c2c-484c-a2bf-4132fdbd343a)

![select_model_5](https://github.com/eliranwong/toolmate/assets/25262722/b88f3950-a898-4fbf-8691-c4789caeb441)

# Run Setup Tool

Run setup tool `tmsetup`:

> tmsetup -b

# Edit in Interactive Mode

Enter either `.backend` or `.model` in ToolMate AI interactive prompt.

# Edit config.py manually

You can also edit manually the folloinwg values in config.py:

(Remarks: Edit config.py only when the app is closed)